<!--- 
	csw-map-google-generic-rh.cfm

	This 'generic' render handler render handler implements the 'getGenericFieldMappingsArray' function below to describe the available field that can be mapped.

	The logic above the function, retrieves the appropriate data and renders a Google Map.

	Note that for 'generic' render handlers the mapped data, if any, will always be passed in the following structure:
		Attributes.ElementInfo.ElementData.PropertyValues
	This is an array of one or more items, with a sub-structure named 'values'.
	Values is a structure with members as defined by the getGenericFieldMappingsArray() function.

	This generic render handler assumes these fields:
		- ID - hidden (gets a default value)
		- Name - Required
		- Latitude (floating point number (positive or negative))
		- Longitude (floating point number (positive or negative))
		- Title
		- Zoom  (integer)
		- Markers  (custom element data manager)

	Properties:
		- Width (css class)				- Width class
		- Height (in pixels)				- Height of Map in pixles
		- Zoom  (1-20)						- Google Maps Zoom level
		- Alignment (css class)			- alignment of map in container
		- Padding (style specifier) 	- padding around the map
		- Background Color
		- Background Image
		- Background Image Focal Point
		- Service API Key
	
	Version: [2018-01-03 11:30 am]
--->

<cfscript>
	// Create the Icon Textblock Component 
	csWidget = CreateObject('component','csw-map-google');
	
	// load necessary resources
	csWidget.loadResources();

	// exit if all we're doing is detecting required resources
	if( Request.RenderState.RenderMode EQ "getResources" )
		exit;

	if( NOT structKeyExists(attributes,'elementinfo') )
		exit;

	// Load the Properties from the metadata form
	props = csWidget.loadProperties(Attributes.ElementInfo,Variables.Caller);	
	
	// Make sure we have Props data
	if( NOT csWidget.hasProperties(props) )
		exit;

	// Get the element Data and Render the items
	if( StructKeyExists(Attributes.ElementInfo.ElementData, 'PropertyValues') )
		csWidget.getAndRenderItems( Attributes.ElementInfo.ElementData, props );
</cfscript>

<!--- ////////////////////////////////////////////////////////////////////////// --->
<!--- //////////////////   GENERIC RENDER HANDLER FUNCTIONS   ////////////////// --->
<!--- ////////////////////////////////////////////////////////////////////////// --->

<!---
	This is the function that is called by CommonSpot when this render handler is registred,
	allowing the user to map the fields of the source element to this render handler.

	Here we expose a structure to build describing the possible fields. Each fieldMappingArray
	item is a structure with the following 3 fields:
		- FieldName
		- Description
		- Required
--->
<cffunction name="getGenericFieldMappingsArray" returntype="array" access="private" output="no">
	<cfscript>
		var fieldMappingArray = ArrayNew(1);
		var fieldDetailsStruct = StructNew();

		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'id';
		fieldDetailsStruct.Description = 'Unique identifier for this marker.';
		fieldDetailsStruct.Required = 1;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Name';
		fieldDetailsStruct.Description = 'The internal name for the marker.';
		fieldDetailsStruct.Required = 1;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Longitude';
		fieldDetailsStruct.Description = "Starting location for this map. Specifies the east-west position of a point on the Earth's surface.";
		fieldDetailsStruct.Required = 1;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Latitude';
		fieldDetailsStruct.Description = "Starting location for this map. Specifies the north-south position of a point on the Earth's surface.";
		fieldDetailsStruct.Required = 1;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Title';
		fieldDetailsStruct.Description = 'The title for the marker.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'icon';
		fieldDetailsStruct.Description = 'Typically a pointer-type icon is used like you would see on Google Maps.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'infoWindowHTML';
		fieldDetailsStruct.Description = 'An info window can be created for each marker using specified HTML.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'animated';
		fieldDetailsStruct.Description = 'Checking this box will cause the marker to drop from the top of the map down to its location when created.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		return fieldMappingArray;
	</cfscript>
</cffunction>
